@@ -14,6 +14,7 @@ describe 'keystone' do
       :osfamily               => 'Debian',
       :operatingsystem        => 'Debian',
       :operatingsystemrelease => '7.0',
+      :os                     => { :name  => 'Debian', :family => 'Debian', :release => { :major => '7', :minor => '0' } },
     }))
   end
 
@@ -26,16 +27,13 @@ describe 'keystone' do
       'admin_bind_host'                    => '0.0.0.0',
       'public_port'                        => '5000',
       'admin_port'                         => '35357',
-      'debug'                              => false,
-      'use_stderr'                         => true,
       'catalog_type'                       => 'sql',
       'catalog_driver'                     => false,
       'token_provider'                     => 'fernet',
-      'token_driver'                       => 'sql',
+      'password_hash_algorithm'            => '<SERVICE DEFAULT>',
+      'password_hash_rounds'               => '<SERVICE DEFAULT>',
       'revoke_driver'                      => 'sql',
       'revoke_by_id'                       => true,
-      'cache_dir'                          => '/var/cache/keystone',
-      'memcache_servers'                   => '<SERVICE DEFAULT>',
       'cache_backend'                      => '<SERVICE DEFAULT>',
       'cache_backend_argument'             => '<SERVICE DEFAULT>',
       'cache_enabled'                      => '<SERVICE DEFAULT>',
@@ -50,21 +48,15 @@ describe 'keystone' do
       'manage_service'                     => true,
       'database_connection'                => 'sqlite:////var/lib/keystone/keystone.db',
       'database_idle_timeout'              => '200',
-      'signing_certfile'                   => '<SERVICE DEFAULT>',
-      'signing_keyfile'                    => '<SERVICE DEFAULT>',
-      'signing_ca_certs'                   => '<SERVICE DEFAULT>',
-      'signing_ca_key'                     => '<SERVICE DEFAULT>',
-      'signing_cert_subject'               => '<SERVICE DEFAULT>',
-      'signing_key_size'                   => '<SERVICE DEFAULT>',
       'default_transport_url'              => '<SERVICE DEFAULT>',
       'notification_transport_url'         => '<SERVICE DEFAULT>',
       'rabbit_heartbeat_timeout_threshold' => '<SERVICE DEFAULT>',
       'rabbit_heartbeat_rate'              => '<SERVICE DEFAULT>',
+      'amqp_durable_queues'                => '<SERVICE DEFAULT>',
       'admin_workers'                      => 20,
       'public_workers'                     => 20,
       'member_role_id'                     => '<SERVICE DEFAULT>',
       'member_role_name'                   => '<SERVICE DEFAULT>',
-      'paste_config'                       => '<SERVICE DEFAULT>',
       'sync_db'                            => true,
       'purge_config'                       => false,
       'keystone_user'                      => 'keystone',
@@ -80,15 +72,14 @@ describe 'keystone' do
       'admin_port'                         => '35358',
       'admin_token'                        => 'service_token_override',
       'admin_password'                     => 'admin_openstack_password',
-      'debug'                              => true,
-      'use_stderr'                         => false,
       'catalog_type'                       => 'template',
       'token_provider'                     => 'uuid',
-      'token_driver'                       => 'kvs',
+      'password_hash_algorithm'            => 'pbkdf2_sha512',
+      'password_hash_rounds'               => '29000',
       'revoke_driver'                      => 'kvs',
       'revoke_by_id'                       => false,
       'public_endpoint'                    => 'https://localhost:5000/v2.0/',
-      'admin_endpoint'                     => 'https://localhost:35357/v2.0/',
+      'admin_endpoint'                     => 'https://localhost:5000/v2.0/',
       'enable_ssl'                         => true,
       'ssl_certfile'                       => '/etc/keystone/ssl/certs/keystone.pem',
       'ssl_keyfile'                        => '/etc/keystone/ssl/private/keystonekey.pem',
@@ -99,22 +90,15 @@ describe 'keystone' do
       'manage_service'                     => true,
       'database_connection'                => 'mysql://a:b@c/d',
       'database_idle_timeout'              => '300',
-      'enable_pki_setup'                   => true,
-      'signing_certfile'                   => '/etc/keystone/ssl/certs/signing_cert.pem',
-      'signing_keyfile'                    => '/etc/keystone/ssl/private/signing_key.pem',
-      'signing_ca_certs'                   => '/etc/keystone/ssl/certs/ca.pem',
-      'signing_ca_key'                     => '/etc/keystone/ssl/private/cakey.pem',
-      'signing_cert_subject'               => '/C=US/ST=Unset/L=Unset/O=Unset/CN=www.example.com',
-      'signing_key_size'                   => 2048,
       'default_transport_url'              => 'rabbit://user:pass@host:1234/virt',
       'notification_transport_url'         => 'rabbit://user:pass@host:1234/virt',
       'rabbit_heartbeat_timeout_threshold' => '60',
       'rabbit_heartbeat_rate'              => '10',
       'rabbit_ha_queues'                   => true,
+      'amqp_durable_queues'                => true,
       'default_domain'                     => 'other_domain',
       'member_role_id'                     => '123456789',
       'member_role_name'                   => 'othermember',
-      'paste_config'                       => '/usr/share/keystone/keystone-paste.ini',
       'using_domain_config'                => false,
       'keystone_user'                      => 'test_user',
       'keystone_group'                     => 'test_group',
@@ -175,8 +159,6 @@ describe 'keystone' do
        'admin_port',
        'member_role_id',
        'member_role_name',
-       'debug',
-       'use_stderr'
       ].each do |config|
         is_expected.to contain_keystone_config("DEFAULT/#{config}").with_value(param_hash[config])
       end
@@ -195,20 +177,20 @@ describe 'keystone' do
       param_hash['token_provider']
     ) }
 
-    it 'should contain correct token driver' do
-      is_expected.to contain_keystone_config('token/driver').with_value(param_hash['token_driver'])
-    end
-
     it 'should contain correct revoke driver' do
       is_expected.to contain_keystone_config('revoke/driver').with_value(param_hash['revoke_driver'])
     end
 
-    it 'should contain default revoke_by_id value ' do
-      is_expected.to contain_keystone_config('token/revoke_by_id').with_value(param_hash['revoke_by_id'])
+    it 'should contain password_hash_algorithm' do
+      is_expected.to contain_keystone_config('identity/password_hash_algorithm').with_value(param_hash['password_hash_algorithm'])
     end
 
-    it 'should contain default paste_config' do
-      is_expected.to contain_keystone_config('paste_deploy/config_file').with_value(param_hash['paste_config'])
+    it 'should contain password_hash_rounds' do
+      is_expected.to contain_keystone_config('identity/password_hash_rounds').with_value(param_hash['password_hash_rounds'])
+    end
+
+    it 'should contain default revoke_by_id value ' do
+      is_expected.to contain_keystone_config('token/revoke_by_id').with_value(param_hash['revoke_by_id'])
     end
 
     it 'should ensure proper setting of admin_endpoint and public_endpoint' do
@@ -231,6 +213,7 @@ describe 'keystone' do
     it 'should contain correct rabbit heartbeat configuration' do
       is_expected.to contain_keystone_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value(param_hash['rabbit_heartbeat_timeout_threshold'])
       is_expected.to contain_keystone_config('oslo_messaging_rabbit/heartbeat_rate').with_value(param_hash['rabbit_heartbeat_rate'])
+      is_expected.to contain_keystone_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(param_hash['amqp_durable_queues'])
     end
 
     it 'should remove max_token_size param by default' do
@@ -363,135 +346,6 @@ describe 'keystone' do
           'token_provider' => 'keystone.token.providers.uuid.Provider'
         }
       end
-
-      describe 'pki_setup is disabled by default' do
-        it { is_expected.to_not contain_exec('keystone-manage pki_setup') }
-        it { is_expected.to_not contain_file('/var/cache/keystone').with_ensure('directory') }
-      end
-    end
-
-    describe 'when configuring as PKI' do
-      let :params do
-        {
-          'enable_pki_setup'     => true,
-          'admin_token'          => 'service_token',
-          'token_provider'       => 'pki',
-          'signing_certfile'     => '/etc/keystone/ssl/certs/signing_cert.pem',
-          'signing_keyfile'      => '/etc/keystone/ssl/private/signing_key.pem',
-          'signing_ca_certs'     => '/etc/keystone/ssl/certs/ca.pem',
-          'signing_ca_key'       => '/etc/keystone/ssl/private/cakey.pem',
-          'signing_cert_subject' => '/C=US/ST=Unset/L=Unset/O=Unset/CN=www.example.com',
-          'signing_key_size'     => 2048,
-          'keystone_user'        => 'keystone',
-          'keystone_group'       => 'keystone',
-        }
-      end
-
-      it { is_expected.to contain_file('/var/cache/keystone').with_ensure('directory') }
-
-      describe 'when overriding the cache dir' do
-        before do
-          params.merge!(:cache_dir => '/var/lib/cache/keystone')
-        end
-        it { is_expected.to contain_file('/var/lib/cache/keystone') }
-      end
-
-      it { is_expected.to contain_exec('keystone-manage pki_setup').with(
-        :command => "keystone-manage pki_setup --keystone-user #{params['keystone_user']} --keystone-group #{params['keystone_group']}",
-        :creates => '/etc/keystone/ssl/private/signing_key.pem'
-      ) }
-      it { is_expected.to contain_file('/var/cache/keystone').with_ensure('directory') }
-
-      describe 'when overriding the cache dir' do
-        before do
-          params.merge!(:cache_dir => '/var/lib/cache/keystone')
-        end
-        it { is_expected.to contain_file('/var/lib/cache/keystone') }
-      end
-    end
-
-    describe 'when configuring PKI signing cert paths with UUID and with pki_setup disabled' do
-      let :params do
-        {
-          'admin_token'          => 'service_token',
-          'token_provider'       => 'uuid',
-          'enable_pki_setup'     => false,
-          'signing_certfile'     => 'signing_certfile',
-          'signing_keyfile'      => 'signing_keyfile',
-          'signing_ca_certs'     => 'signing_ca_certs',
-          'signing_ca_key'       => 'signing_ca_key',
-          'signing_cert_subject' => 'signing_cert_subject',
-          'signing_key_size'     => 2048
-        }
-      end
-
-      it { is_expected.to_not contain_exec('keystone-manage pki_setup') }
-
-      it 'should contain correct PKI certfile config' do
-        is_expected.to contain_keystone_config('signing/certfile').with_value('signing_certfile')
-      end
-
-      it 'should contain correct PKI keyfile config' do
-        is_expected.to contain_keystone_config('signing/keyfile').with_value('signing_keyfile')
-      end
-
-      it 'should contain correct PKI ca_certs config' do
-        is_expected.to contain_keystone_config('signing/ca_certs').with_value('signing_ca_certs')
-      end
-
-      it 'should contain correct PKI ca_key config' do
-        is_expected.to contain_keystone_config('signing/ca_key').with_value('signing_ca_key')
-      end
-
-      it 'should contain correct PKI cert_subject config' do
-        is_expected.to contain_keystone_config('signing/cert_subject').with_value('signing_cert_subject')
-      end
-
-      it 'should contain correct PKI key_size config' do
-        is_expected.to contain_keystone_config('signing/key_size').with_value('2048')
-      end
-    end
-
-    describe 'when configuring PKI signing cert paths with pki_setup disabled' do
-      let :params do
-        {
-          'admin_token'          => 'service_token',
-          'token_provider'       => 'pki',
-          'enable_pki_setup'     => false,
-          'signing_certfile'     => 'signing_certfile',
-          'signing_keyfile'      => 'signing_keyfile',
-          'signing_ca_certs'     => 'signing_ca_certs',
-          'signing_ca_key'       => 'signing_ca_key',
-          'signing_cert_subject' => 'signing_cert_subject',
-          'signing_key_size'     => 2048
-        }
-      end
-
-      it { is_expected.to_not contain_exec('keystone-manage pki_setup') }
-
-      it 'should contain correct PKI certfile config' do
-        is_expected.to contain_keystone_config('signing/certfile').with_value('signing_certfile')
-      end
-
-      it 'should contain correct PKI keyfile config' do
-        is_expected.to contain_keystone_config('signing/keyfile').with_value('signing_keyfile')
-      end
-
-      it 'should contain correct PKI ca_certs config' do
-        is_expected.to contain_keystone_config('signing/ca_certs').with_value('signing_ca_certs')
-      end
-
-      it 'should contain correct PKI ca_key config' do
-        is_expected.to contain_keystone_config('signing/ca_key').with_value('signing_ca_key')
-      end
-
-      it 'should contain correct PKI cert_subject config' do
-        is_expected.to contain_keystone_config('signing/cert_subject').with_value('signing_cert_subject')
-      end
-
-      it 'should contain correct PKI key_size config' do
-        is_expected.to contain_keystone_config('signing/key_size').with_value('2048')
-      end
     end
 
     describe 'with invalid catalog_type' do
@@ -500,7 +354,7 @@ describe 'keystone' do
           :catalog_type => 'invalid' }
       end
 
-      it_raises "a Puppet::Error", /validate_re\(\): "invalid" does not match "template|sql"/
+      it { should raise_error(Puppet::Error) }
     end
 
     describe 'when configuring catalog driver' do
@@ -560,10 +414,9 @@ describe 'keystone' do
     let :params do
       {
         'admin_token'                  => 'service_token',
-        'memcache_servers'             => [ 'SERVER1:11211', 'SERVER2:11211' ],
-        'token_driver'                 => 'memcache',
         'cache_backend'                => 'dogpile.cache.memcached',
         'cache_backend_argument'       => ['url:SERVER1:12211'],
+        'cache_memcache_servers'       => 'SERVER1:11211,SERVER2:11211',
         'memcache_dead_retry'          => '60',
         'memcache_socket_timeout'      => '2',
         'memcache_pool_maxsize'        => '1000',
@@ -571,8 +424,7 @@ describe 'keystone' do
       }
     end
 
-    it { is_expected.to contain_keystone_config("memcache/servers").with_value('SERVER1:11211,SERVER2:11211') }
-    it { is_expected.to contain_keystone_config('cache/enabled').with_value(true) }
+    it { is_expected.to contain_keystone_config('cache/enabled').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('token/caching').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.memcached') }
     it { is_expected.to contain_keystone_config('cache/backend_argument').with_value('url:SERVER1:12211') }
@@ -585,36 +437,57 @@ describe 'keystone' do
     it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('1000') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60') }
     it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211') }
-    it {
-      if facts[:os_package_type] == 'debian'
-        pkg = 'python3-memcache'
-      else
-        pkg = 'python-memcache'
-      end
-      is_expected.to contain_package('python-memcache').with(
-        :name   => pkg,
-        :ensure => 'present'
-      )
-    }
   end
 
   describe 'configure cache memcache servers if set' do
     let :params do
       {
-        'admin_token'                  => 'service_token',
-        'memcache_servers'             => [ 'SERVER1:11211', 'SERVER2:11211' ],
-        'token_driver'                 => 'memcache',
-        'cache_backend'                => 'dogpile.cache.memcached',
-        'cache_backend_argument'       => ['url:SERVER3:12211'],
-        'cache_memcache_servers'       => [ 'SERVER3:11211', 'SERVER4:11211' ],
-        'memcache_dead_retry'          => '60',
-        'memcache_socket_timeout'      => '2',
-        'memcache_pool_maxsize'        => '1000',
-        'memcache_pool_unused_timeout' => '60',
+        'admin_token'                          => 'service_token',
+        'cache_backend'                        => 'dogpile.cache.memcached',
+        'cache_backend_argument'               => ['url:SERVER3:12211'],
+        'cache_memcache_servers'               => [ 'SERVER1:11211', 'SERVER2:11211' ],
+        'memcache_dead_retry'                  => '60',
+        'memcache_socket_timeout'              => '2',
+        'memcache_pool_maxsize'                => '1000',
+        'memcache_pool_unused_timeout'         => '60',
+        'memcache_pool_connection_get_timeout' => '30',
+        'manage_backend_package'               => false,
+      }
+    end
+
+    it { is_expected.to contain_keystone_config('cache/enabled').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_keystone_config('token/caching').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.memcached') }
+    it { is_expected.to contain_keystone_config('cache/backend_argument').with_value('url:SERVER3:12211') }
+    it { is_expected.to contain_keystone_config('memcache/dead_retry').with_value('60') }
+    it { is_expected.to contain_keystone_config('memcache/socket_timeout').with_value('2') }
+    it { is_expected.to contain_keystone_config('memcache/pool_maxsize').with_value('1000') }
+    it { is_expected.to contain_keystone_config('memcache/pool_unused_timeout').with_value('60') }
+    it { is_expected.to contain_keystone_config('cache/memcache_dead_retry').with_value('60') }
+    it { is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('2') }
+    it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('1000') }
+    it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60') }
+    it { is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('30') }
+    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211') }
+    it { is_expected.to contain_oslo__cache('keystone_config').with_manage_backend_package(false) }
+  end
+
+  describe 'configure cache enabled if set' do
+    let :params do
+      {
+        'admin_token'                          => 'service_token',
+        'cache_backend'                        => 'dogpile.cache.memcached',
+        'cache_backend_argument'               => ['url:SERVER3:12211'],
+        'cache_enabled'                        => true,
+        'cache_memcache_servers'               => [ 'SERVER1:11211', 'SERVER2:11211' ],
+        'memcache_dead_retry'                  => '60',
+        'memcache_socket_timeout'              => '2',
+        'memcache_pool_maxsize'                => '1000',
+        'memcache_pool_unused_timeout'         => '60',
+        'memcache_pool_connection_get_timeout' => '30',
       }
     end
 
-    it { is_expected.to contain_keystone_config("memcache/servers").with_value('SERVER1:11211,SERVER2:11211') }
     it { is_expected.to contain_keystone_config('cache/enabled').with_value(true) }
     it { is_expected.to contain_keystone_config('token/caching').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.memcached') }
@@ -627,60 +500,18 @@ describe 'keystone' do
     it { is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('2') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('1000') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60') }
-    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER3:11211,SERVER4:11211') }
-    it { is_expected.to contain_package('python-memcache').with(
-      :name   => 'python-memcache',
-      :ensure => 'present'
-    ) }
-  end
-
-  describe 'configure cache enabled if set' do
-    let :params do
-      {
-        'admin_token'                  => 'service_token',
-        'memcache_servers'             => [ 'SERVER1:11211', 'SERVER2:11211' ],
-        'token_driver'                 => 'memcache',
-        'cache_backend'                => 'dogpile.cache.memcached',
-        'cache_backend_argument'       => ['url:SERVER3:12211'],
-        'cache_enabled'                => false,
-        'cache_memcache_servers'       => [ 'SERVER3:11211', 'SERVER4:11211' ],
-        'memcache_dead_retry'          => '60',
-        'memcache_socket_timeout'      => '2',
-        'memcache_pool_maxsize'        => '1000',
-        'memcache_pool_unused_timeout' => '60',
-      }
-    end
-
-    it { is_expected.to contain_keystone_config("memcache/servers").with_value('SERVER1:11211,SERVER2:11211') }
-    it { is_expected.to contain_keystone_config('cache/enabled').with_value(false) }
-    it { is_expected.to contain_keystone_config('token/caching').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.memcached') }
-    it { is_expected.to contain_keystone_config('cache/backend_argument').with_value('url:SERVER3:12211') }
-    it { is_expected.to contain_keystone_config('memcache/dead_retry').with_value('60') }
-    it { is_expected.to contain_keystone_config('memcache/socket_timeout').with_value('2') }
-    it { is_expected.to contain_keystone_config('memcache/pool_maxsize').with_value('1000') }
-    it { is_expected.to contain_keystone_config('memcache/pool_unused_timeout').with_value('60') }
-    it { is_expected.to contain_keystone_config('cache/memcache_dead_retry').with_value('60') }
-    it { is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('2') }
-    it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('1000') }
-    it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60') }
-    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER3:11211,SERVER4:11211') }
-    it { is_expected.to contain_package('python-memcache').with(
-      :name   => 'python-memcache',
-      :ensure => 'present'
-    ) }
+    it { is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('30') }
+    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211') }
   end
 
   describe 'configure memcache servers with a string' do
     let :params do
       default_params.merge({
-        'memcache_servers'       => 'SERVER1:11211,SERVER2:11211',
-        'cache_memcache_servers' => 'SERVER3:11211,SERVER4:11211'
+        'cache_memcache_servers' => 'SERVER1:11211,SERVER2:11211'
       })
     end
 
-    it { is_expected.to contain_keystone_config("memcache/servers").with_value('SERVER1:11211,SERVER2:11211') }
-    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER3:11211,SERVER4:11211') }
+    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211') }
   end
 
   describe 'do not configure memcache servers when not set' do
@@ -693,7 +524,6 @@ describe 'keystone' do
     it { is_expected.to contain_keystone_config("cache/backend").with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config("cache/backend_argument").with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config("cache/debug_cache_backend").with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config("memcache/servers").with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('memcache/dead_retry').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('memcache/pool_maxsize').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('memcache/pool_unused_timeout').with_value('<SERVICE DEFAULT>') }
@@ -701,6 +531,7 @@ describe 'keystone' do
     it { is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('<SERVICE DEFAULT>') }
   end
 
@@ -710,7 +541,7 @@ describe 'keystone' do
         'admin_token'     => 'service_token',
         'enable_ssl'      => true,
         'public_endpoint' => 'https://localhost:5000/v2.0/',
-        'admin_endpoint'  => 'https://localhost:35357/v2.0/',
+        'admin_endpoint'  => 'https://localhost:5000/v2.0/',
       }
     end
     it {is_expected.to contain_keystone_config('ssl/enable').with_value(true)}
@@ -720,7 +551,7 @@ describe 'keystone' do
     it {is_expected.to contain_keystone_config('ssl/ca_key').with_value('/etc/keystone/ssl/private/cakey.pem')}
     it {is_expected.to contain_keystone_config('ssl/cert_subject').with_value('/C=US/ST=Unset/L=Unset/O=Unset/CN=localhost')}
     it {is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('https://localhost:5000/v2.0/')}
-    it {is_expected.to contain_keystone_config('DEFAULT/admin_endpoint').with_value('https://localhost:35357/v2.0/')}
+    it {is_expected.to contain_keystone_config('DEFAULT/admin_endpoint').with_value('https://localhost:5000/v2.0/')}
   end
   describe 'when disabling SSL' do
     let :params do
@@ -868,15 +699,15 @@ describe 'keystone' do
       {
         :admin_token       => 'service_token',
         :validate_service  => true,
-        :validate_auth_url => 'http://some.host:35357/v2.0',
-        :admin_endpoint    => 'http://some.host:35357'
+        :validate_auth_url => 'http://some.host:5000/v2.0',
+        :admin_endpoint    => 'http://some.host:5000'
       }
     end
 
-    it { is_expected.to contain_keystone_config('DEFAULT/admin_endpoint').with_value('http://some.host:35357') }
+    it { is_expected.to contain_keystone_config('DEFAULT/admin_endpoint').with_value('http://some.host:5000') }
     it { is_expected.to contain_class('keystone::service').with(
       'validate'       => true,
-      'admin_endpoint' => 'http://some.host:35357/v2.0'
+      'admin_endpoint' => 'http://some.host:5000/v2.0'
     )}
   end
 
@@ -885,13 +716,13 @@ describe 'keystone' do
       {
         :admin_token      => 'service_token',
         :validate_service => true,
-        :admin_endpoint   => 'http://some.host:35357'
+        :admin_endpoint   => 'http://some.host:5000'
       }
     end
 
     it { is_expected.to contain_class('keystone::service').with(
       'validate'       => true,
-      'admin_endpoint' => 'http://some.host:35357'
+      'admin_endpoint' => 'http://some.host:5000'
     )}
   end
 
@@ -1170,7 +1001,8 @@ describe 'keystone' do
       @default_facts.merge(global_facts.merge({
         :osfamily               => 'RedHat',
         :operatingsystem        => 'RedHat',
-        :operatingsystemrelease => '7.0'
+        :operatingsystemrelease => '7.0',
+        :os                     => { :name  => 'RedHat', :family => 'RedHat', :release => { :major => '7', :minor => '0' } },
       }))
     end
 
@@ -1190,7 +1022,8 @@ describe 'keystone' do
       @default_facts.merge(global_facts.merge({
         :osfamily               => 'Debian',
         :operatingsystem        => 'Debian',
-        :operatingsystemrelease => '7.0'
+        :operatingsystemrelease => '7.0',
+        :os                     => { :name  => 'Debian', :family => 'Debian', :release => { :major => '7', :minor => '0' } },
       }))
     end
 
@@ -1237,10 +1070,8 @@ describe 'keystone' do
           'domain_config_directory' => 'this/is/not/an/absolute/path'
         })
       end
-      it 'should raise an error' do
-        expect { should contain_file('/etc/keystone/domains') }
-          .to raise_error(Puppet::Error, %r(this/is/not/an/absolute/path" is not))
-      end
+
+      it { should raise_error(Puppet::Error) }
     end
     describe 'when setting domain directory and not using domain config' do
       let :params do
